# Updating the pango.modules file:
chroot . /sbin/ldconfig 2> /dev/null
if [ -x /usr/bin/update-pango-querymodules ]; then
  /usr/bin/update-pango-querymodules
fi
( cd usr/lib ; rm -rf libpangox-1.0.so )
( cd usr/lib ; ln -sf libpangox-1.0.so.0.2203.1 libpangox-1.0.so )
( cd usr/lib ; rm -rf libpangoft2-1.0.so.0 )
( cd usr/lib ; ln -sf libpangoft2-1.0.so.0.2203.1 libpangoft2-1.0.so.0 )
( cd usr/lib ; rm -rf libpangoxft-1.0.so.0 )
( cd usr/lib ; ln -sf libpangoxft-1.0.so.0.2203.1 libpangoxft-1.0.so.0 )
( cd usr/lib ; rm -rf libpango-1.0.so.0 )
( cd usr/lib ; ln -sf libpango-1.0.so.0.2203.1 libpango-1.0.so.0 )
( cd usr/lib ; rm -rf libpangoft2-1.0.so )
( cd usr/lib ; ln -sf libpangoft2-1.0.so.0.2203.1 libpangoft2-1.0.so )
( cd usr/lib ; rm -rf libpangox-1.0.so.0 )
( cd usr/lib ; ln -sf libpangox-1.0.so.0.2203.1 libpangox-1.0.so.0 )
( cd usr/lib ; rm -rf libpangoxft-1.0.so )
( cd usr/lib ; ln -sf libpangoxft-1.0.so.0.2203.1 libpangoxft-1.0.so )
( cd usr/lib ; rm -rf libpango-1.0.so )
( cd usr/lib ; ln -sf libpango-1.0.so.0.2203.1 libpango-1.0.so )
